@@ -1,11 +1,12 @@
 """
 @author: Roman Matusevich
 """
-import binascii
 import rlp
 import hashlib
 import copy
-from mintersdk import MinterConvertor, MinterHelper, MinterPrefix
+from mintersdk import (
+    MinterHelper, PREFIX_ADDR, PREFIX_TX, PREFIX_PUBKEY, PREFIX_CHECK
+)
 from mintersdk.sdk import ECDSA
 from mintersdk.sdk.wallet import MinterWallet
 
@@ -105,7 +106,7 @@ class MinterTx(object):
             signed_tx hash (str)
         """
         tx_rlp = rlp.encode(list(tx_struct.values()))
-        return binascii.hexlify(tx_rlp).decode()
+        return tx_rlp.hex()
 
     def generate_signature(self, private_key):
         """
@@ -124,7 +125,7 @@ class MinterTx(object):
 
         # Create signature
         signature = ECDSA.sign(keccak, private_key)
-        signature = binascii.hexlify(rlp.encode(signature)).decode()
+        signature = rlp.encode(signature).hex()
 
         return signature
 
@@ -191,11 +192,7 @@ class MinterTx(object):
         else:
             # Add multisig address to signature
             signature_data = [
-                MinterHelper.hex2bin(
-                    MinterPrefix.remove_prefix(
-                        string=ms_address, prefix=MinterPrefix.ADDRESS
-                    )
-                ),
+                bytes.fromhex(MinterHelper.prefix_remove(ms_address)),
                 []
             ]
 
@@ -224,10 +221,10 @@ class MinterTx(object):
 
         # Create SHA256
         sha = hashlib.sha256()
-        sha.update(binascii.unhexlify(self.signed_tx))
+        sha.update(bytes.fromhex(self.signed_tx))
 
         # Return first 40 symbols with prefix
-        return MinterPrefix.TRANSACTION + sha.hexdigest()[:40]
+        return MinterHelper.prefix_add(sha.hexdigest()[:40], PREFIX_TX)
 
     def _structure_from_instance(self):
         """
@@ -241,7 +238,7 @@ class MinterTx(object):
             'nonce': self.nonce,
             'chain_id': self.chain_id,
             'gas_price': self.gas_price,
-            'gas_coin': MinterConvertor.encode_coin_name(self.gas_coin),
+            'gas_coin': MinterHelper.encode_coin_name(self.gas_coin),
             'payload': self.payload,
             'service_data': self.service_data,
             'signature_type': self.signature_type
@@ -257,7 +254,7 @@ class MinterTx(object):
         """
 
         structure.update({
-            'gas_coin': MinterConvertor.decode_coin_name(structure['gas_coin'])
+            'gas_coin': MinterHelper.decode_coin_name(structure['gas_coin'])
         })
 
         return structure
@@ -292,44 +289,55 @@ class MinterTx(object):
             MinterTx child instance
         """
 
-        tx = rlp.decode(binascii.unhexlify(raw_tx))
+        tx = rlp.decode(bytes.fromhex(raw_tx))
+
+        # Try to decode payload
+        try:
+            payload = tx[6].decode()
+        except UnicodeDecodeError:
+            payload = tx[6]
+
+        # Try to decode service data
+        try:
+            service_data = tx[7].decode()
+        except UnicodeDecodeError:
+            service_data = tx[7]
 
         # Populate structure dict with decoded tx data
         struct = copy.copy(cls._STRUCTURE_DICT)
         struct.update({
-            'nonce': int(binascii.hexlify(tx[0]), 16),
-            'chain_id': int(binascii.hexlify(tx[1]), 16),
-            'gas_price': int(binascii.hexlify(tx[2]), 16),
+            'nonce': int.from_bytes(tx[0], 'big'),
+            'chain_id': int.from_bytes(tx[1], 'big'),
+            'gas_price': int.from_bytes(tx[2], 'big'),
             'gas_coin': tx[3].decode(),
-            'type': int(binascii.hexlify(tx[4]), 16),
-            'payload': tx[6].decode().replace(chr(0), ''),
-            'service_data': tx[7].decode().replace(chr(0), ''),
-            'signature_type': int(binascii.hexlify(tx[8]), 16)
+            'type': int.from_bytes(tx[4], 'big'),
+            'payload': payload,
+            'service_data': service_data,
+            'signature_type': int.from_bytes(tx[8], 'big')
         })
 
         # Get signature data
         signature_data = rlp.decode(tx[9])
         if struct['signature_type'] == cls.SIGNATURE_SINGLE_TYPE:
             signature_data = {
-                'v': int(binascii.hexlify(signature_data[0]), 16),
-                'r': binascii.hexlify(signature_data[1]).decode(),
-                's': binascii.hexlify(signature_data[2]).decode()
+                'v': int.from_bytes(signature_data[0], 'big'),
+                'r': signature_data[1].hex(),
+                's': signature_data[2].hex()
             }
         else:
             # Decode signatures
             signatures = []
             for signature in signature_data[1]:
                 signatures.append({
-                    'v': int(binascii.hexlify(signature[0]), 16),
-                    'r': binascii.hexlify(signature[1]).decode(),
-                    's': binascii.hexlify(signature[2]).decode()
+                    'v': int.from_bytes(signature[0], 'big'),
+                    'r': signature[1].hex(),
+                    's': signature[2].hex()
                 })
 
             # Create decoded signature data
             signature_data = {
-                'from_mx': (
-                    MinterPrefix.ADDRESS +
-                    MinterHelper.bin2hex(signature_data[0])
+                'from_mx': MinterHelper.prefix_add(
+                    signature_data[0].hex(), PREFIX_ADDR
                 ),
                 'signatures': signatures
             }
@@ -405,7 +413,7 @@ class MinterTx(object):
 
         # Otherwise (single signature tx), recover public key and get
         # address from public key
-        # Unhexlify (convert to bin (ascii)) all non-numeric dict values
+        # Unhexlify hexdigit dict values to bytes
         tx = MinterHelper.hex2bin_recursive(tx)
 
         # Encode tx data to RLP
@@ -416,9 +424,9 @@ class MinterTx(object):
         _keccak = MinterHelper.keccak_hash(tx_rlp)
 
         # Recover public key
-        public_key = (
-            MinterPrefix.PUBLIC_KEY +
-            ECDSA.recover(_keccak, tuple(signature_data.values()))
+        public_key = MinterHelper.prefix_add(
+            ECDSA.recover(_keccak, tuple(signature_data.values())),
+            PREFIX_PUBKEY
         )
 
         return MinterWallet.get_address_from_public_key(public_key)
@@ -446,11 +454,8 @@ class MinterTx(object):
         # Convert signature data from verbose dict to needed list of
         # signatures
         signature_data = [
-            MinterHelper.hex2bin(
-                MinterPrefix.remove_prefix(
-                    string=tx.signature_data['from_mx'],
-                    prefix=MinterPrefix.ADDRESS
-                )
+            bytes.fromhex(
+                MinterHelper.prefix_remove(tx.signature_data['from_mx'])
             ),
             []
         ]
@@ -496,9 +501,9 @@ class MinterTx(object):
         Returns:
             signature (list[int])
         """
-        signature = binascii.unhexlify(signature)
+        signature = bytes.fromhex(signature)
         signature = rlp.decode(signature)
-        signature = [int(binascii.hexlify(item), 16) for item in signature]
+        signature = [int.from_bytes(item, 'big') for item in signature]
 
         return signature
 
@@ -546,18 +551,10 @@ class MinterBuyCoinTx(MinterTx):
         struct.update({
             'type': self.TYPE,
             'data': {
-                'coin_to_buy': MinterConvertor.encode_coin_name(
-                    self.coin_to_buy
-                ),
-                'value_to_buy': MinterConvertor.convert_value(
-                    value=self.value_to_buy, to='pip'
-                ),
-                'coin_to_sell': MinterConvertor.encode_coin_name(
-                    self.coin_to_sell
-                ),
-                'max_value_to_sell': MinterConvertor.convert_value(
-                    value=self.max_value_to_sell, to='pip'
-                )
+                'coin_to_buy': MinterHelper.encode_coin_name(self.coin_to_buy),
+                'value_to_buy': MinterHelper.to_pip(self.value_to_buy),
+                'coin_to_sell': MinterHelper.encode_coin_name(self.coin_to_sell),
+                'max_value_to_sell': MinterHelper.to_pip(self.max_value_to_sell)
             }
         })
 
@@ -572,19 +569,17 @@ class MinterBuyCoinTx(MinterTx):
         # Convert data values to verbose.
         # Data will be passed as additional kwarg
         kwargs['data'].update({
-            'coin_to_buy': MinterConvertor.decode_coin_name(
+            'coin_to_buy': MinterHelper.decode_coin_name(
                 kwargs['data']['coin_to_buy']
             ),
-            'value_to_buy': MinterConvertor.convert_value(
-                value=MinterHelper.bin2int(kwargs['data']['value_to_buy']),
-                to='bip'
+            'value_to_buy': MinterHelper.to_bip(
+                int.from_bytes(kwargs['data']['value_to_buy'], 'big')
             ),
-            'coin_to_sell': MinterConvertor.decode_coin_name(
+            'coin_to_sell': MinterHelper.decode_coin_name(
                 kwargs['data']['coin_to_sell']
             ),
-            'max_value_to_sell': MinterConvertor.convert_value(
-                value=MinterHelper.bin2int(kwargs['data']['max_value_to_sell']),
-                to='bip'
+            'max_value_to_sell': MinterHelper.to_bip(
+                int.from_bytes(kwargs['data']['max_value_to_sell'], 'big')
             )
         })
 
@@ -642,17 +637,11 @@ class MinterCreateCoinTx(MinterTx):
             'type': self.TYPE,
             'data': {
                 'name': self.name,
-                'symbol': MinterConvertor.encode_coin_name(self.symbol),
-                'initial_amount': MinterConvertor.convert_value(
-                    value=self.initial_amount, to='pip'
-                ),
-                'initial_reserve': MinterConvertor.convert_value(
-                    value=self.initial_reserve, to='pip'
-                ),
+                'symbol': MinterHelper.encode_coin_name(self.symbol),
+                'initial_amount': MinterHelper.to_pip(self.initial_amount),
+                'initial_reserve': MinterHelper.to_pip(self.initial_reserve),
                 'crr': '' if self.crr == 0 else self.crr,
-                'max_supply': MinterConvertor.convert_value(
-                    value=self.max_supply, to='pip'
-                )
+                'max_supply': MinterHelper.to_pip(self.max_supply)
             }
         })
 
@@ -668,19 +657,16 @@ class MinterCreateCoinTx(MinterTx):
         # Data will be passed as additional kwarg
         kwargs['data'].update({
             'name': kwargs['data']['name'].decode(),
-            'symbol': MinterConvertor.decode_coin_name(kwargs['data']['symbol']),
-            'initial_amount': MinterConvertor.convert_value(
-                value=MinterHelper.bin2int(kwargs['data']['initial_amount']),
-                to='bip'
+            'symbol': MinterHelper.decode_coin_name(kwargs['data']['symbol']),
+            'initial_amount': MinterHelper.to_bip(
+                int.from_bytes(kwargs['data']['initial_amount'], 'big')
             ),
-            'initial_reserve': MinterConvertor.convert_value(
-                value=MinterHelper.bin2int(kwargs['data']['initial_reserve']),
-                to='bip'
+            'initial_reserve': MinterHelper.to_bip(
+                int.from_bytes(kwargs['data']['initial_reserve'], 'big')
             ),
-            'crr': MinterHelper.bin2int(kwargs['data']['crr']),
-            'max_supply': MinterConvertor.convert_value(
-                value=MinterHelper.bin2int(kwargs['data']['max_supply']),
-                to='bip'
+            'crr': int.from_bytes(kwargs['data']['crr'], 'big'),
+            'max_supply': MinterHelper.to_bip(
+                int.from_bytes(kwargs['data']['max_supply'], 'big')
             )
         })
 
@@ -737,21 +723,15 @@ class MinterDeclareCandidacyTx(MinterTx):
         struct.update({
             'type': self.TYPE,
             'data': {
-                'address': MinterHelper.hex2bin(
-                    MinterPrefix.remove_prefix(
-                        string=self.address, prefix=MinterPrefix.ADDRESS
-                    )
+                'address': bytes.fromhex(
+                    MinterHelper.prefix_remove(self.address)
                 ),
-                'pub_key': MinterHelper.hex2bin(
-                    MinterPrefix.remove_prefix(
-                        string=self.pub_key, prefix=MinterPrefix.PUBLIC_KEY
-                    )
+                'pub_key': bytes.fromhex(
+                    MinterHelper.prefix_remove(self.pub_key)
                 ),
                 'commission': '' if self.commission == 0 else self.commission,
-                'coin': MinterConvertor.encode_coin_name(self.coin),
-                'stake': MinterConvertor.convert_value(
-                    value=self.stake, to='pip'
-                )
+                'coin': MinterHelper.encode_coin_name(self.coin),
+                'stake': MinterHelper.to_pip(self.stake)
             }
         })
 
@@ -766,18 +746,16 @@ class MinterDeclareCandidacyTx(MinterTx):
         # Convert data values to verbose.
         # Data will be passed as additional kwarg
         kwargs['data'].update({
-            'address': (
-                MinterPrefix.ADDRESS +
-                MinterHelper.bin2hex(kwargs['data']['address'])
+            'address': MinterHelper.prefix_add(
+                kwargs['data']['address'].hex(), PREFIX_ADDR
             ),
-            'pub_key': (
-                MinterPrefix.PUBLIC_KEY +
-                MinterHelper.bin2hex(kwargs['data']['pub_key'])
+            'pub_key': MinterHelper.prefix_add(
+                kwargs['data']['pub_key'].hex(), PREFIX_PUBKEY
             ),
-            'commission': MinterHelper.bin2int(kwargs['data']['commission']),
-            'coin': MinterConvertor.decode_coin_name(kwargs['data']['coin']),
-            'stake': MinterConvertor.convert_value(
-                value=MinterHelper.bin2int(kwargs['data']['stake']), to='bip'
+            'commission': int.from_bytes(kwargs['data']['commission'], 'big'),
+            'coin': MinterHelper.decode_coin_name(kwargs['data']['coin']),
+            'stake': MinterHelper.to_bip(
+                int.from_bytes(kwargs['data']['stake'], 'big')
             )
         })
 
@@ -822,15 +800,11 @@ class MinterDelegateTx(MinterTx):
         struct.update({
             'type': self.TYPE,
             'data': {
-                'pub_key': MinterHelper.hex2bin(
-                    MinterPrefix.remove_prefix(
-                        self.pub_key, MinterPrefix.PUBLIC_KEY
-                    )
+                'pub_key': bytes.fromhex(
+                    MinterHelper.prefix_remove(self.pub_key)
                 ),
-                'coin': MinterConvertor.encode_coin_name(self.coin),
-                'stake': MinterConvertor.convert_value(
-                    value=self.stake, to='pip'
-                )
+                'coin': MinterHelper.encode_coin_name(self.coin),
+                'stake': MinterHelper.to_pip(self.stake)
             }
         })
 
@@ -844,13 +818,12 @@ class MinterDelegateTx(MinterTx):
         # Convert data values to verbose.
         # Data will be passed as additional kwarg
         kwargs['data'].update({
-            'pub_key': (
-                MinterPrefix.PUBLIC_KEY +
-                MinterHelper.bin2hex(kwargs['data']['pub_key'])
+            'pub_key': MinterHelper.prefix_add(
+                kwargs['data']['pub_key'].hex(), PREFIX_PUBKEY
             ),
-            'coin': MinterConvertor.decode_coin_name(kwargs['data']['coin']),
-            'stake': MinterConvertor.convert_value(
-                value=MinterHelper.bin2int(kwargs['data']['stake']), to='bip'
+            'coin': MinterHelper.decode_coin_name(kwargs['data']['coin']),
+            'stake': MinterHelper.to_bip(
+                int.from_bytes(kwargs['data']['stake'], 'big')
             )
         })
 
@@ -898,10 +871,8 @@ class MinterRedeemCheckTx(MinterTx):
         struct.update({
             'type': self.TYPE,
             'data': {
-                'check': MinterHelper.hex2bin(
-                    MinterPrefix.remove_prefix(self.check, MinterPrefix.CHECK)
-                ),
-                'proof': MinterHelper.hex2bin(self.proof)
+                'check': bytes.fromhex(MinterHelper.prefix_remove(self.check)),
+                'proof': bytes.fromhex(self.proof)
             }
         })
 
@@ -916,8 +887,10 @@ class MinterRedeemCheckTx(MinterTx):
         # Convert data values to verbose.
         # Data will be passed as additional kwarg
         kwargs['data'].update({
-            'check': MinterPrefix.CHECK + MinterHelper.bin2hex(kwargs['data']['check']),
-            'proof': MinterHelper.bin2hex(kwargs['data']['proof'])
+            'check': MinterHelper.prefix_add(
+                kwargs['data']['check'].hex(), PREFIX_CHECK
+            ),
+            'proof': kwargs['data']['proof'].hex()
         })
 
         # Populate data key values as kwargs
@@ -965,15 +938,9 @@ class MinterSellAllCoinTx(MinterTx):
         struct.update({
             'type': self.TYPE,
             'data': {
-                'coin_to_sell': MinterConvertor.encode_coin_name(
-                    self.coin_to_sell
-                ),
-                'coin_to_buy': MinterConvertor.encode_coin_name(
-                    self.coin_to_buy
-                ),
-                'min_value_to_buy': MinterConvertor.convert_value(
-                    value=self.min_value_to_buy, to='pip'
-                )
+                'coin_to_sell': MinterHelper.encode_coin_name(self.coin_to_sell),
+                'coin_to_buy': MinterHelper.encode_coin_name(self.coin_to_buy),
+                'min_value_to_buy': MinterHelper.to_pip(self.min_value_to_buy)
             }
         })
 
@@ -988,15 +955,14 @@ class MinterSellAllCoinTx(MinterTx):
         # Convert data values to verbose.
         # Data will be passed as additional kwarg
         kwargs['data'].update({
-            'coin_to_sell': MinterConvertor.decode_coin_name(
+            'coin_to_sell': MinterHelper.decode_coin_name(
                 kwargs['data']['coin_to_sell']
             ),
-            'coin_to_buy': MinterConvertor.decode_coin_name(
+            'coin_to_buy': MinterHelper.decode_coin_name(
                 kwargs['data']['coin_to_buy']
             ),
-            'min_value_to_buy': MinterConvertor.convert_value(
-                value=MinterHelper.bin2int(kwargs['data']['min_value_to_buy']),
-                to='bip'
+            'min_value_to_buy': MinterHelper.to_bip(
+                int.from_bytes(kwargs['data']['min_value_to_buy'], 'big')
             )
         })
 
@@ -1049,18 +1015,10 @@ class MinterSellCoinTx(MinterTx):
         struct.update({
             'type': self.TYPE,
             'data': {
-                'coin_to_sell': MinterConvertor.encode_coin_name(
-                    self.coin_to_sell
-                ),
-                'value_to_sell': MinterConvertor.convert_value(
-                    value=self.value_to_sell, to='pip'
-                ),
-                'coin_to_buy': MinterConvertor.encode_coin_name(
-                    self.coin_to_buy
-                ),
-                'min_value_to_buy': MinterConvertor.convert_value(
-                    value=self.min_value_to_buy, to='pip'
-                )
+                'coin_to_sell': MinterHelper.encode_coin_name(self.coin_to_sell),
+                'value_to_sell': MinterHelper.to_pip(self.value_to_sell),
+                'coin_to_buy': MinterHelper.encode_coin_name(self.coin_to_buy),
+                'min_value_to_buy': MinterHelper.to_pip(self.min_value_to_buy)
             }
         })
 
@@ -1075,19 +1033,17 @@ class MinterSellCoinTx(MinterTx):
         # Convert data values to verbose.
         # Data will be passed as additional kwarg
         kwargs['data'].update({
-            'coin_to_sell': MinterConvertor.decode_coin_name(
+            'coin_to_sell': MinterHelper.decode_coin_name(
                 kwargs['data']['coin_to_sell']
             ),
-            'value_to_sell': MinterConvertor.convert_value(
-                value=MinterHelper.bin2int(kwargs['data']['value_to_sell']),
-                to='bip'
+            'value_to_sell': MinterHelper.to_bip(
+                int.from_bytes(kwargs['data']['value_to_sell'], 'big')
             ),
-            'coin_to_buy': MinterConvertor.decode_coin_name(
+            'coin_to_buy': MinterHelper.decode_coin_name(
                 kwargs['data']['coin_to_buy']
             ),
-            'min_value_to_buy': MinterConvertor.convert_value(
-                value=MinterHelper.bin2int(kwargs['data']['min_value_to_buy']),
-                to='bip'
+            'min_value_to_buy': MinterHelper.to_bip(
+                int.from_bytes(kwargs['data']['min_value_to_buy'], 'big')
             )
         })
 
@@ -1131,15 +1087,9 @@ class MinterSendCoinTx(MinterTx):
         struct.update({
             'type': self.TYPE,
             'data': {
-                'coin': MinterConvertor.encode_coin_name(self.coin),
-                'to': MinterHelper.hex2bin(
-                    MinterPrefix.remove_prefix(
-                        string=self.to, prefix=MinterPrefix.ADDRESS
-                    )
-                ),
-                'value': MinterConvertor.convert_value(
-                    value=self.value, to='pip'
-                )
+                'coin': MinterHelper.encode_coin_name(self.coin),
+                'to': bytes.fromhex(MinterHelper.prefix_remove(self.to)),
+                'value': MinterHelper.to_pip(self.value)
             }
         })
 
@@ -1154,13 +1104,12 @@ class MinterSendCoinTx(MinterTx):
         # Convert data values to verbose.
         # Data will be passed as additional kwarg
         kwargs['data'].update({
-            'coin': MinterConvertor.decode_coin_name(kwargs['data']['coin']),
-            'to': (
-                MinterPrefix.ADDRESS +
-                MinterHelper.bin2hex(kwargs['data']['to'])
+            'coin': MinterHelper.decode_coin_name(kwargs['data']['coin']),
+            'to': MinterHelper.prefix_add(
+                kwargs['data']['to'].hex(), PREFIX_ADDR
             ),
-            'value': MinterConvertor.convert_value(
-                value=MinterHelper.bin2int(kwargs['data']['value']), to='bip'
+            'value': MinterHelper.to_bip(
+                int.from_bytes(kwargs['data']['value'], 'big')
             )
         })
 
@@ -1226,13 +1175,9 @@ class MinterMultiSendCoinTx(MinterTx):
         # Populate multi data from each single tx.
         for item in self.txs:
             struct['data']['txs'].append([
-                MinterConvertor.encode_coin_name(item['coin'].upper()),
-                MinterHelper.hex2bin(
-                    MinterPrefix.remove_prefix(
-                        string=item['to'], prefix=MinterPrefix.ADDRESS
-                    )
-                ),
-                MinterConvertor.convert_value(value=item['value'], to='pip')
+                MinterHelper.encode_coin_name(item['coin'].upper()),
+                bytes.fromhex(MinterHelper.prefix_remove(item['to'])),
+                MinterHelper.to_pip(item['value'])
             ])
 
         return struct
@@ -1247,11 +1192,9 @@ class MinterMultiSendCoinTx(MinterTx):
         # Data will be passed as additional kwarg
         for index, item in enumerate(kwargs['data']['txs']):
             kwargs['data']['txs'][index] = {
-                'coin': MinterConvertor.decode_coin_name(item[0]),
-                'to': MinterPrefix.ADDRESS + MinterHelper.bin2hex(item[1]),
-                'value': MinterConvertor.convert_value(
-                    value=MinterHelper.bin2int(item[2]), to='bip'
-                )
+                'coin': MinterHelper.decode_coin_name(item[0]),
+                'to': MinterHelper.prefix_add(item[1].hex(), PREFIX_ADDR),
+                'value': MinterHelper.to_pip(int.from_bytes(item[2], 'big'))
             }
 
         # Populate data key values as kwargs
@@ -1296,10 +1239,8 @@ class MinterSetCandidateOffTx(MinterTx):
         struct.update({
             'type': self.TYPE,
             'data': {
-                'pub_key': MinterHelper.hex2bin(
-                    MinterPrefix.remove_prefix(
-                        string=self.pub_key, prefix=MinterPrefix.PUBLIC_KEY
-                    )
+                'pub_key': bytes.fromhex(
+                    MinterHelper.prefix_remove(self.pub_key)
                 )
             }
         })
@@ -1315,9 +1256,8 @@ class MinterSetCandidateOffTx(MinterTx):
         # Convert data values to verbose.
         # Data will be passed as additional kwarg
         kwargs['data'].update({
-            'pub_key': (
-                MinterPrefix.PUBLIC_KEY +
-                MinterHelper.bin2hex(kwargs['data']['pub_key'])
+            'pub_key': MinterHelper.prefix_add(
+                kwargs['data']['pub_key'].hex(), PREFIX_PUBKEY
             )
         })
 
@@ -1361,10 +1301,8 @@ class MinterSetCandidateOnTx(MinterTx):
         struct.update({
             'type': self.TYPE,
             'data': {
-                'pub_key': MinterHelper.hex2bin(
-                    MinterPrefix.remove_prefix(
-                        string=self.pub_key, prefix=MinterPrefix.PUBLIC_KEY
-                    )
+                'pub_key': bytes.fromhex(
+                    MinterHelper.prefix_remove(self.pub_key)
                 )
             }
         })
@@ -1380,9 +1318,8 @@ class MinterSetCandidateOnTx(MinterTx):
         # Convert data values to verbose.
         # Data will be passed as additional kwarg
         kwargs['data'].update({
-            'pub_key': (
-                MinterPrefix.PUBLIC_KEY +
-                MinterHelper.bin2hex(kwargs['data']['pub_key'])
+            'pub_key': MinterHelper.prefix_add(
+                kwargs['data']['pub_key'].hex(), PREFIX_PUBKEY
             )
         })
 
@@ -1430,15 +1367,11 @@ class MinterUnbondTx(MinterTx):
         struct.update({
             'type': self.TYPE,
             'data': {
-                'pub_key': MinterHelper.hex2bin(
-                    MinterPrefix.remove_prefix(
-                        string=self.pub_key, prefix=MinterPrefix.PUBLIC_KEY
-                    )
+                'pub_key': bytes.fromhex(
+                    MinterHelper.prefix_remove(self.pub_key)
                 ),
-                'coin': MinterConvertor.encode_coin_name(self.coin),
-                'value': MinterConvertor.convert_value(
-                    value=self.value, to='pip'
-                )
+                'coin': MinterHelper.encode_coin_name(self.coin),
+                'value': MinterHelper.to_pip(self.value)
             }
         })
 
@@ -1453,13 +1386,12 @@ class MinterUnbondTx(MinterTx):
         # Convert data values to verbose.
         # Data will be passed as additional kwarg
         kwargs['data'].update({
-            'pub_key': (
-                MinterPrefix.PUBLIC_KEY +
-                MinterHelper.bin2hex(kwargs['data']['pub_key'])
+            'pub_key': MinterHelper.prefix_add(
+                kwargs['data']['pub_key'].hex(), PREFIX_PUBKEY
             ),
-            'coin': MinterConvertor.decode_coin_name(kwargs['data']['coin']),
-            'value': MinterConvertor.convert_value(
-                value=MinterHelper.bin2int(kwargs['data']['value']), to='bip'
+            'coin': MinterHelper.decode_coin_name(kwargs['data']['coin']),
+            'value': MinterHelper.to_bip(
+                int.from_bytes(kwargs['data']['value'], 'big')
             )
         })
 
@@ -1509,20 +1441,14 @@ class MinterEditCandidateTx(MinterTx):
         struct.update({
             'type': self.TYPE,
             'data': {
-                'pub_key': MinterHelper.hex2bin(
-                    MinterPrefix.remove_prefix(
-                        string=self.pub_key, prefix=MinterPrefix.PUBLIC_KEY
-                    )
+                'pub_key': bytes.fromhex(
+                    MinterHelper.prefix_remove(self.pub_key)
                 ),
-                'reward_address': MinterHelper.hex2bin(
-                    MinterPrefix.remove_prefix(
-                        string=self.reward_address, prefix=MinterPrefix.ADDRESS
-                    )
+                'reward_address': bytes.fromhex(
+                    MinterHelper.prefix_remove(self.reward_address)
                 ),
-                'owner_address': MinterHelper.hex2bin(
-                    MinterPrefix.remove_prefix(
-                        string=self.owner_address, prefix=MinterPrefix.ADDRESS
-                    )
+                'owner_address': bytes.fromhex(
+                    MinterHelper.prefix_remove(self.owner_address)
                 )
             }
         })
@@ -1538,17 +1464,14 @@ class MinterEditCandidateTx(MinterTx):
         # Convert data values to verbose.
         # Data will be passed as additional kwarg
         kwargs['data'].update({
-            'pub_key': (
-                MinterPrefix.PUBLIC_KEY +
-                MinterHelper.bin2hex(kwargs['data']['pub_key'])
+            'pub_key': MinterHelper.prefix_add(
+                kwargs['data']['pub_key'].hex(), PREFIX_PUBKEY
             ),
-            'reward_address': (
-                MinterPrefix.ADDRESS +
-                MinterHelper.bin2hex(kwargs['data']['reward_address'])
+            'reward_address': MinterHelper.prefix_add(
+                kwargs['data']['reward_address'].hex(), PREFIX_ADDR
             ),
-            'owner_address': (
-                MinterPrefix.ADDRESS +
-                MinterHelper.bin2hex(kwargs['data']['owner_address'])
+            'owner_address': MinterHelper.prefix_add(
+                kwargs['data']['owner_address'].hex(), PREFIX_ADDR
             )
         })
 
